@@ -40,24 +40,26 @@ def get_letter_font_coords(x: int, y: int, w: int, h: int) -> tuple:
     return (coords1_x, coords1_y)
 
 
-def make_image(wordle_list: list) -> Image:
+def make_image(wordle_list: list, image_list: list, font_path: str) -> Image:
     """Makes an image from wordle data
 
     Args:
         wordle_list (list): a list, consisting of 6 elements. Each element is also a list with this structure: [str word, int letter_state, int letter_state, int letter_state, int letter_state, int letter_state]. Letter states - 0: letter is grey, 1: letter is yellow, 2: letter is green.
+        image_list (list): a list, containing 4 paths to images: 1st is for the main image, 2nd is for grey letter backgrounds, 3rd is for yellow, 4th is for green.
+        font_path (str): path to a font for letters.
 
     Returns:
         Image: the generated image
     """
 
-    main_image = Image.open(r"./images/main.png")
-    grey_image = Image.open(r"./images/grey.png")
-    yellow_image = Image.open(r"./images/yellow.png")
-    green_image = Image.open(r"./images/green.png")
+    main_image = Image.open(image_list[0])
+    grey_image = Image.open(image_list[1])
+    yellow_image = Image.open(image_list[2])
+    green_image = Image.open(image_list[3])
     letter_images = [grey_image, yellow_image, green_image]
 
     drawer = ImageDraw.Draw(main_image)
-    font = ImageFont.truetype("font.ttf", 60)
+    font = ImageFont.truetype(font_path, 60)
 
     text_color = (255, 255, 255)
     outline_color = (0, 0, 0)
